@@ -23,6 +23,9 @@
 #include "perl.h"
 #include "XSUB.h"
 
+#ifndef mXPUSHp
+#define mXPUSHp(p,l) STMT_START { EXTEND(sp,1); sv_setpvn(PUSHmort al, (p), (l)); } STMT_END
+#endif
 
 #define PERL_MONGO_CALL_BOOT(name)  perl_mongo_call_xs (aTHX_ name, cv, mark)
 
@@ -136,7 +139,7 @@ SV *perl_mongo_bson_to_sv (buffer *buf);
 void perl_mongo_sv_to_bson (buffer *buf, SV *sv, AV *ids);
 
 int perl_mongo_resize_buf (buffer*, int);
-void perl_mongo_serialize_key(buffer*, const char*, void*);
+void perl_mongo_serialize_key(buffer *buf, const char *str, int is_insert);
 void perl_mongo_serialize_size(char*, buffer*);
 void perl_mongo_serialize_double(buffer*, double);
 void perl_mongo_serialize_string(buffer*, const char*, int);
